@@ -70,9 +70,10 @@ def load_media_review(media_review_path: Union[str, Path]) -> MediaReview:
                 content = getattr(Content, a.tag)
                 for k, v in a.attrib.items():
                     setattr(content, k, v)
-                contents.append(content)
+                contents.append(content())
+
             note.contents = contents
 
-            review.add_note(note)
+        review.add_note(note)
 
     return review
